@@ -4,7 +4,7 @@
 
 __author__ = 'Micah Smith'
 __email__ = 'micahs@mit.edu'
-__version__ = '0.5.0'
+__version__ = '0.7.1'
 
 from jupyterlab.labapp import LabApp
 
@@ -26,6 +26,12 @@ def load_jupyter_server_extension(app: LabApp):
         app (notebook.notebookapp.NotebookApp)
             Notebook application instance
     """
+
+    # initialize app instance
+    from .app import BalletApp
+    BalletApp.clear_instance()
+    BalletApp.instance(config=app.config)
+
     setup_handlers(app.web_app, EXTENSION_URL_PATH)
     app.log.info('Registered ballet-submit-labextension extension at URL path /%s',
                  EXTENSION_URL_PATH)
